-- $Id: schema-pgsql.txt 23894 2007-05-01 17:24:07Z leeh $

CREATE TABLE users (
	id SERIAL,
	username VARCHAR(10) NOT NULL,
	password VARCHAR(35) NOT NULL,
	email VARCHAR(100),
	suspender VARCHAR(30),
	suspend_reason VARCHAR(SUSPEND50),
	suspend_time INTEGER DEFAULT '0',
	reg_time INTEGER,
	last_time INTEGER,
	flags INTEGER,
	verify_token VARCHAR(8),
	language VARCHAR(255) DEFAULT '',
	PRIMARY KEY(id)
);
ALTER TABLE users ADD UNIQUE(username);

CREATE TABLE users_resetpass (
	username VARCHAR(10) NOT NULL,
	token VARCHAR(10),
	time INTEGER,
	PRIMARY KEY(username)
);
CREATE INDEX resetpass_time_idx ON users_resetpass (time);

CREATE TABLE users_resetemail (
	username VARCHAR(10) NOT NULL,
	token VARCHAR(10),
	email VARCHAR(100) DEFAULT NULL,
	time INTEGER,
	PRIMARY KEY(username)
);
CREATE INDEX resetemail_time_idx ON users_resetemail (time);

CREATE TABLE users_sync (
	id SERIAL,
	hook VARCHAR(50) NOT NULL,
	data TEXT,
	PRIMARY KEY(id)
);

CREATE TABLE nicks (
	nickname VARCHAR(9) NOT NULL,
	username VARCHAR(10) NOT NULL,
	reg_time INTEGER,
	last_time INTEGER,
	flags INTEGER,
	PRIMARY KEY(nickname),
	FOREIGN KEY(username) REFERENCES users (username) MATCH FULL
);

CREATE TABLE channels (
	chname VARCHAR(200) NOT NULL,
	topic VARCHAR(160),
	url VARCHAR(100),
	createmodes VARCHAR(50),
	enforcemodes VARCHAR(50),
	tsinfo INTEGER,
	reg_time INTEGER,
	last_time INTEGER,
	flags INTEGER,
	suspender VARCHAR(30),
	suspend_reason VARCHAR(SUSPEND50),
	suspend_time INTEGER DEFAULT '0',
	PRIMARY KEY(chname)
);

CREATE TABLE channels_dropowner (
	chname VARCHAR(200) NOT NULL,
	token VARCHAR(10),
	time INTEGER,
	PRIMARY KEY(chname)
);
CREATE INDEX dropowner_time_idx ON channels_dropowner (time);

CREATE TABLE members (
	chname VARCHAR(200) NOT NULL,
	username VARCHAR(10) NOT NULL,
	lastmod VARCHAR(10) NOT NULL,
	level INT,
	flags INTEGER,
	suspend INT,
	PRIMARY KEY(chname, username),
	FOREIGN KEY(chname) REFERENCES channels (chname) MATCH FULL,
	FOREIGN KEY(username) REFERENCES users (username) MATCH FULL
);
CREATE INDEX members_chname_idx ON members (chname);
CREATE INDEX members_username_idx ON members (username);

CREATE TABLE bans (
	chname VARCHAR(200) NOT NULL,
	mask VARCHAR(84) NOT NULL,
	reason VARCHAR(50) NOT NULL,
	username VARCHAR(10) NOT NULL,
	level INT,
	hold INT,
	PRIMARY KEY(chname, mask),
	FOREIGN KEY(chname) REFERENCES channels (chname) MATCH FULL
--	FOREIGN KEY(username) REFERENCES users (username) MATCH FULL
--	Username might not exist?
);
CREATE INDEX bans_chname_idx ON bans (chname);

CREATE TABLE operbot (
	chname VARCHAR(200) NOT NULL,
	tsinfo INTEGER,
	oper VARCHAR(30),
	PRIMARY KEY(chname)
);

CREATE TABLE operserv (
	chname VARCHAR(200) NOT NULL,
	tsinfo INTEGER,
	oper VARCHAR(30),
	PRIMARY KEY(chname)
);

CREATE TABLE jupes (
	servername VARCHAR(63) NOT NULL,
	reason VARCHAR(50) NOT NULL,
	PRIMARY KEY(servername)
);

CREATE TABLE operbans (
	type CHAR(1) NOT NULL,
	mask VARCHAR(200) NOT NULL,
	reason VARCHAR(50) NOT NULL,
	operreason VARCHAR(50),
	hold INTEGER,
	create_time INTEGER,
	oper VARCHAR(30),
	remove BOOL,
	flags INTEGER,
	PRIMARY KEY(type, mask)
);

CREATE TABLE operbans_regexp (
	id SERIAL,
	regex VARCHAR(255) NOT NULL,
	reason VARCHAR(50) NOT NULL,
	hold INTEGER,
	create_time INTEGER,
	oper VARCHAR(30),
	PRIMARY KEY(id)
);

CREATE TABLE operbans_regexp_neg (
	id SERIAL,
	parent_id BIGINT NOT NULL,
	regex VARCHAR(255) NOT NULL,
	oper VARCHAR(30) NOT NULL,
	PRIMARY KEY(id)
);

CREATE TABLE global_welcome (
	id INTEGER,
	text TEXT,
	PRIMARY KEY(id)
);

CREATE TABLE email_banned_domain (
	domain VARCHAR(255) NOT NULL,
	PRIMARY KEY(domain)
);

CREATE TABLE ignore_hosts (
	hostname VARCHAR(255) NOT NULL,
	oper VARCHAR(30) NOT NULL,
	reason VARCHAR(255) NOT NULL,
	PRIMARY KEY(hostname)
);

CREATE TABLE memos (
	id SERIAL,
	user_id BIGINT NOT NULL,
	source_id BIGINT NOT NULL,
	source VARCHAR(10) NOT NULL,
	timestamp INTEGER DEFAULT '0',
	flags INTEGER DEFAULT '0',
	text TEXT,
	PRIMARY KEY(id),
	FOREIGN KEY (user_id) REFERENCES users (id) ON DELETE CASCADE
);

